@@ -1,5 +1,7 @@
 """
-Main interface for codestar-notifications service literal definitions.
+Type annotations for codestar-notifications service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/literals.html)
 
 Usage::
 
